AppFile class
- Annotations
Constructors
- AppFile({String fileKey = '', String? fileName, String? filePath, Uint8List? fileBytes, String? fileUrl, String? fileExtension, String? fileType, int? size, XFile? xFile})
-
const
- AppFile.fromPlatformFile(PlatformFile file, {String fileKey = ''})
-
factory
- AppFile.fromXFile(XFile file, {String fileKey = '', Uint8List? bytes})
-
factory
- AppFile.local({required String path, String fileKey = '', String? fileName})
-
factory
- AppFile.memory({required Uint8List bytes, required String name, String fileKey = ''})
-
factory
- AppFile.network({required String url, String fileKey = '', String? name})
-
factory
Properties
- displayName → String
-
no setter
- fileBytes → Uint8List?
-
final
- fileExtension → String?
-
final
- fileKey → String
-
final
- fileName → String?
-
final
- filePath → String?
-
final
- fileType → String?
-
final
- fileUrl → String?
-
final
- hasBytes → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPreviewSource → bool
-
no setter
- isImage → bool
-
no setter
- isRemote → bool
-
no setter
- resolvedExtension → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int?
-
final
- xFile → XFile?
-
final
Methods
-
copyWith(
{String? fileKey, String? fileName, String? filePath, Uint8List? fileBytes, String? fileUrl, String? fileExtension, String? fileType, int? size, XFile? xFile, bool clearBytes = false}) → AppFile -
ensureBytesLoaded(
) → Future< AppFile> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited